@@ -50,6 +50,7 @@ system! {
         action::Action,
         amount_of_substance::AmountOfSubstance,
         angle::Angle,
+        angular_absement::AngularAbsement,
         angular_acceleration::AngularAcceleration,
         angular_jerk::AngularJerk,
         angular_velocity::AngularVelocity,
@@ -93,6 +94,7 @@ system! {
         inductance::Inductance,
         information::Information,
         information_rate::InformationRate,
+        inverse_velocity::InverseVelocity,
         jerk::Jerk,
         length::Length,
         linear_density_of_states::LinearDensityOfStates,
@@ -111,6 +113,7 @@ system! {
         mass_concentration::MassConcentration,
         mass_density::MassDensity,
         mass_flux::MassFlux,
+        mass_per_energy::MassPerEnergy,
         mass_rate::MassRate,
         molality::Molality,
         molar_concentration::MolarConcentration,
@@ -123,6 +126,7 @@ system! {
         moment_of_inertia::MomentOfInertia,
         momentum::Momentum,
         power::Power,
+        power_rate::PowerRate,
         pressure::Pressure,
         radiant_exposure::RadiantExposure,
         radioactivity::Radioactivity,
