@@ -987,7 +987,7 @@ macro_rules! system {
             U: Units<V> + ?Sized,
             V: $crate::num::Num + $crate::Conversion<V> + $crate::lib::fmt::Debug,
         {
-            fn fmt<'a>(&self, f: &mut $crate::lib::fmt::Formatter<'a>) -> $crate::lib::fmt::Result {
+            fn fmt(&self, f: &mut $crate::lib::fmt::Formatter) -> $crate::lib::fmt::Result {
                 self.value.fmt(f)
                 $(.and_then(|_| {
                     let d = <D::$symbol as $crate::typenum::Integer>::to_i32();
@@ -1514,7 +1514,7 @@ macro_rules! system {
                         V: Num + Conversion<V> + fmt::$style,
                         N: Unit + Conversion<V, T = V::T>,
                     {
-                        fn fmt<'a>(&self, f: &mut fmt::Formatter<'a>) -> fmt::Result {
+                        fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
                             let value = from_base::<D, U, V, N>(&self.quantity.value);
 
                             value.fmt(f)?;
